/*

  RFID RC522 Modul 13.56 MHz (Card / Brick UID Access Control)

  Parts required:
  - Arduino Board
  - RFID RC522 Modul 13.56 MHz
  - RFID MIFARE 1K Card or Brick

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 27 Jan 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <SPI.h>                                                          // include library SPI.h
#include <MFRC522.h>                                                      // include library MFRC522.h

#define SS_PIN 10                                                         // set SDA pin as digital pin 10
#define RST_PIN 9                                                         // set Reset pin as digital pin 9

#define RFID_UID_Code "59 28 48 83"                                       // set RFID_UID_Code as "59 28 48 83" - use your card number here to gain access

MFRC522 mfrc522(SS_PIN, RST_PIN);                                         // create object from MFRC522 as mfrc522

void setup()
{
  Serial.begin(9600);                                                     // start Serial Monitor for communication
  SPI.begin();                                                            // start SPI
  mfrc522.PCD_Init();                                                     // initialize mfrc522
  Serial.println("   RFID Access Control System   ");                     // print text to Serial Monitor
  Serial.println("--------------------------------");                     // print text to Serial Monitor
  Serial.println("Place your card at the reader...");                     // print text to Serial Monitor
  Serial.println();                                                       // print empty line to Serial Monitor

}
void loop()
{
  if ( ! mfrc522.PICC_IsNewCardPresent())                                 // looking for new card places on the reader
  {
    return;                                                               // if not return
  }

  if ( ! mfrc522.PICC_ReadCardSerial())                                   // select the card been read from the card reader
  {
    return;                                                               // if not return
  }
  //Show UID on serial monitor
  Serial.print("UID tag :");                                              // print the UID tag to Serial Monitor

  // mfrc522 routine for reading the card UID infomation
  String content = "";
  byte letter;
  for (byte i = 0; i < mfrc522.uid.size; i++)
  {
    Serial.print(mfrc522.uid.uidByte[i] < 0x10 ? " 0" : " ");
    Serial.print(mfrc522.uid.uidByte[i], HEX);
    content.concat(String(mfrc522.uid.uidByte[i] < 0x10 ? " 0" : " "));
    content.concat(String(mfrc522.uid.uidByte[i], HEX));
  }

  // check as the UID code has access to the system
  Serial.println();                                                       // print empty line to Serial Monitor
  Serial.print("Message : ");                                             // print text to Serial Monitor
  content.toUpperCase();                                                  // set the value to uppercase characters
  if (content.substring(1) == RFID_UID_Code)                              // check the value is the same as the access granted card UID
  {
    Serial.println("Authorized access");                                  // print text to Serial Monitor
    Serial.println();                                                     // print empty line to Serial Monitor
    delay(3000);                                                          // wait 3000ms
  }

  else   {                                                                // if the card UID not match the value do
    Serial.println(" Access denied");                                     // print text to Serial Monitor
    delay(3000);                                                          // wait 3000ms
  }
  Serial.println();                                                       // print empty line to Serial Monitor
}
